actor = {}
actor_mt = {__index = actor}

function getSprites(file, id)
local sprite = {}
sprite.img = love.graphics.newImage(file)
sprite.img:setFilter("nearest", "nearest")
sprite.frames = {}
local modifierx = 0
local modifiery = 0
if (id > 4) then 
modifierx = -4 
modifiery = 1
end
for a=1,4 do
	sprite.frames[a] = {}
	for b = 1,3 do
	sprite.frames[a][b] = love.graphics.newQuad((b-1)*constants.charw+((id-1+modifierx)*3*constants.charw), (a-1)*constants.charh+(4*constants.charh*modifiery), constants.charw, constants.charh, sprite.img:getWidth(), sprite.img:getHeight())
	end
end
return sprite
end

function checkCollision(objs, tgtx, tgty)
local retvalue = true
for a=1,#objs do
	for b=1,objs[a].w/constants.base do
		if ((objs[a].x/constants.base)+b == tgtx) then 
			for c=1,objs[a].h/constants.base do
			if ((objs[a].y/constants.base)+c == tgty) then retvalue = nil end
			end
		end
	end
end
for a=1,#actor do
	if (tgtx == actor[a].tx) then
		if (tgty == actor[a].ty) then
			retvalue = nil
		end
	end
end
return retvalue
end

function actor:new(sprite, x, y, f)
unit = constants.base*constants.scale
local id = #actor+1
local o = {}
o["id"] = id
o["sprite"] = sprite
o["x"] = x*unit
o["y"] = y*unit
o.px = x*unit
o.py = y*unit
o.tx = x
o.ty = y
o.visible = true
o.solid = true
o.moving = false
o.moveBogus = false
o.running = 0
o.state = f
o.frame = 1
o.pos = 0
o.direction = 1
o.speed = 600
o.sb = love.graphics.newSpriteBatch(o.sprite.img, 1)
setmetatable(o, actor_mt)
actor[id] = o
return o
end

function actor:update(dt)
if self.moving or self.moveBogus then
	if (math.ceil(self.pos) < 100) then
		self.pos = self.pos + self.speed*dt+(500*dt*self.running)
	else
		self.frame = self.frame + 1 * self.direction
		if self.frame == 3 then self.direction = -1 end
		if self.frame == 1 then self.direction = 1 end
		self.pos = 0
	end
end

if self.moveBogus then
	if love.keyboard.isDown("w") then self.state = 4
	elseif love.keyboard.isDown("a") then self.state = 2
	elseif love.keyboard.isDown("s") then self.state = 1
	elseif love.keyboard.isDown("d") then self.state = 3 
	else 
		self.moving = false
		self.moveBogus = false
	end
end

if self.py == math.floor(self.y) and self.px == math.floor(self.x) then
	if self.moveBogus ~= true then
		self.moving = false
	else
	end
self.x = math.floor(self.x)
self.y = math.floor(self.y)
end

if self.px < math.floor(self.x) then 
self.moving = true
self.state = 2
self.x = self.x - 100*dt-(self.running*dt*100)
elseif self.px > math.floor(self.x) then 
self.moving = true
self.state = 3
self.x = self.x + 100*dt+(self.running*dt*100) 
elseif self.py < math.floor(self.y) then 
self.moving = true
self.state = 4
self.y = self.y - 100*dt-(self.running*dt*100)
elseif self.py > math.floor(self.y) then
self.moving = true 
self.state = 1
self.y = self.y + 100*dt+(self.running*dt*100)
end

self.tx = self.px/(constants.scale*constants.base)
self.ty = self.py/(constants.scale*constants.base)
end

function actor:draw(cam)
self.sb:clear()
if (self.visible == true) then
if (self.moving ~= true) then
self.sb:addq(self.sprite.frames[self.state][2], math.floor(400+math.floor(self.x)-cam.x), math.floor(300+math.floor(self.y)-cam.y), 0, constants.scale, constants.scale, 36, 24)
else
self.sb:addq(self.sprite.frames[self.state][self.frame], math.floor(400+math.floor(self.x)-cam.x), math.floor(300+math.floor(self.y)-cam.y), 0, constants.scale, constants.scale, 36, 24)
end
love.graphics.draw(self.sb, 0, 0)
end
love.graphics.print(self.x .. "\n" .. self.y .. "\n" .. self.tx .. "\n" .. self.ty, 20, 20)
end

function actor:control(map, cam)
if love.keyboard.isDown("w") and self.py == math.floor(self.y) and self.px == math.floor(self.x) and self.ty > 1 then
	if checkCollision(map.objects, self.tx, self.ty-1) then 
		self:move("up")
	else
		self.moveBogus = true
		self.moving = true
	end
elseif love.keyboard.isDown("a") and self.px == math.floor(self.x) and self.py == math.floor(self.y) and self.tx > 1 then 
	if checkCollision(map.objects, self.tx-1, self.ty) then 
		self:move("left")
	else
		self.moveBogus = true
		self.moving = true
	end
elseif love.keyboard.isDown("s") and self.py == math.floor(self.y) and self.px == math.floor(self.x) and self.ty < map.header.height then 
	if checkCollision(map.objects, self.tx, self.ty+1) then 
		self:move("down")
	else
		self.moveBogus = true
		self.moving = true
	end
elseif love.keyboard.isDown("d") and self.px == math.floor(self.x) and self.py == math.floor(self.y) and self.tx < map.header.width then 
	if checkCollision(map.objects, self.tx+1, self.ty) then 
		self:move("right")
	else
		self.moveBogus = true
		self.moving = true
	end
end

cam.x = self.x
cam.y = self.y

return cam


end

function actor:move(dir)
if dir == "up" then self.py = self.py - constants.base*constants.scale end
if dir == "down" then self.py = self.py + constants.base*constants.scale end
if dir == "right" then self.px = self.px + constants.base*constants.scale end
if dir == "left" then self.px = self.px - constants.base*constants.scale end
end




